Module: RubynCode::Agent::BackgroundJobHandler
- Included in:
- Loop
- Defined in:
- lib/rubyn_code/agent/background_job_handler.rb
Overview
Manages background job polling, waiting, and notification draining for the agent loop.
Manages background job polling, waiting, and notification draining for the agent loop.