Module: RubynCode::Agent::SystemPromptBuilder
Overview
Assembles the system prompt for the agent loop, including base personality, plan-mode instructions, memories, instincts, project instructions, and available skills/tools.
Constant Summary collapse
- INSTRUCTION_FILES =
%w[RUBYN.md CLAUDE.md AGENT.md].freeze